# gen_password 
## python package to generate automatically random complex password 




# gen_password 

[![Build Status](https://travis-ci.org/username/package-name.svg?branch=master)](https://travis-ci.org/username/package-name)
[![Coverage Status](https://coveralls.io/repos/github/username/package-name/badge.svg?branch=master)](https://coveralls.io/github/username/package-name?branch=master)
[![PyPI version](https://badge.fury.io/py/package-name.svg)](https://badge.fury.io/py/package-name)
[![License](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)

A brief description of your package goes here. Include any unique features or benefits of your package.

## Table of Contents

- [Installation](#install)
- [Usage](#usage)

## Installation [install]

To install this package, you can use `pip` : 

```python
pip install gen_passwrd
```






## Usage [usage]

Here's a brief overview of how you can use this package. Provide more detail if necessary.

#### ***Generation of complex password***
```python
import gen_passwrd as gen_pass

pass_generator = gen_pass.Password()

complex_password1 = pass_generator.generate_password()
# output : B/z4CY8s5A('z]D (lenght = 15) 

complex_password2 = pass_generator.generate_password()
# output : 9]inB#Q?y3*[tSk  (lenght = 15) 

complex_password3 = pass_generator.generate_password(30)
# output : -e`}5$#dkU[t-:hyWB{DjtYr1872cQ  (lenght = 30)

complex_password4 = pass_generator.generate_password(10)
# output : }]'iqa(?#!  (lenght = 10)
```
---
#### ***Generation of password containing only alphabetic letters***
```python
import gen_passwrd as gen_pass

letters_password1 = pass_generator.generate_password_letters()
# output (lenght = 15 [default value]): XejyBkSBJXkrYNf 

letters_password1 = pass_generator.generate_password_letters(30)
# output (lenght = 15): UcbqvMgRZpIRKwfJZRvxzQjxtfEeCC 

letters_password1 = pass_generator.generate_password_letters(10)
# output (lenght = 15): dYNxNnWbDL 


```